@@ -1,21 +1,5 @@
 /* This file is part of Spectacle, the KDE screenshot utility
- * Copyright (C) 2015 Boudhayan Gupta <bgupta@kde.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
+ * SPDX-FileCopyrightText: 2015 Boudhayan Gupta <bgupta@kde.org>
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
@@ -23,41 +7,39 @@
 
 #include <SpectacleCommon.h>
 
-#include <QObject>
+#include <KLocalizedString>
+#include <QDateTime>
 #include <QIODevice>
 #include <QMap>
-#include <QPrinter>
+#include <QObject>
 #include <QPixmap>
-#include <QDateTime>
+#include <QPrinter>
 #include <QUrl>
-#include <KLocalizedString>
 
 class QTemporaryDir;
 
-class ExportManager: public QObject
+class ExportManager : public QObject
 {
     Q_OBJECT
 
     // singleton-ize the class
 
-    public:
-
-    static ExportManager* instance();
-
-    private:
+public:
+    static ExportManager *instance();
 
+private:
     explicit ExportManager(QObject *parent = nullptr);
-    virtual ~ExportManager();
+    ~ExportManager() override;
 
-    ExportManager(ExportManager const&) = delete;
-    void operator= (ExportManager const&) = delete;
+    ExportManager(ExportManager const &) = delete;
+    void operator=(ExportManager const &) = delete;
 
     // now the usual stuff
 
-    public:
-
+public:
     QString defaultSaveLocation() const;
     bool isFileExists(const QUrl &url) const;
+    bool isImageSavedNotInTemp() const;
     void setPixmap(const QPixmap &pixmap);
     QPixmap pixmap() const;
     void updatePixmapTimestamp();
@@ -69,16 +51,16 @@ class ExportManager: public QObject
 
     static const QMap<QString, KLocalizedString> filenamePlaceholders;
 
-    Q_SIGNALS:
+Q_SIGNALS:
 
     void errorMessage(const QString &str);
-    void pixmapChanged(const QPixmap &pixmap);
     void imageSaved(const QUrl &savedAt);
     void imageCopied();
+    void imageLocationCopied(const QUrl &savedAt);
     void imageSavedAndCopied(const QUrl &savedAt);
     void forceNotify(const QUrl &savedAt);
 
-    public Q_SLOTS:
+public Q_SLOTS:
 
     QUrl getAutosaveFilename();
     QUrl tempSave();
@@ -88,15 +70,14 @@ class ExportManager: public QObject
     bool doSaveAs(QWidget *parentWindow = nullptr, bool notify = false);
     void doSaveAndCopy(const QUrl &url = QUrl());
     void doCopyToClipboard(bool notify = false);
+    void doCopyLocationToClipboard(bool notify = false);
     void doPrint(QPrinter *printer);
 
-    private:
-
+private:
     QString truncatedFilename(const QString &filename);
     QString makeAutosaveFilename();
-    using FileNameAlreadyUsedCheck = bool (ExportManager::*)(const QUrl&) const;
-    QString autoIncrementFilename(const QString &baseName, const QString &extension,
-                                  FileNameAlreadyUsedCheck isFileNameUsed);
+    using FileNameAlreadyUsedCheck = bool (ExportManager::*)(const QUrl &) const;
+    QString autoIncrementFilename(const QString &baseName, const QString &extension, FileNameAlreadyUsedCheck isFileNameUsed);
     QString makeSaveMimetype(const QUrl &url);
     bool writeImage(QIODevice *device, const QByteArray &format);
     bool save(const QUrl &url);
@@ -104,11 +85,12 @@ class ExportManager: public QObject
     bool remoteSave(const QUrl &url, const QString &mimetype);
     bool isTempFileAlreadyUsed(const QUrl &url) const;
 
+    bool mImageSavedNotInTemp;
     QPixmap mSavePixmap;
     QDateTime mPixmapTimestamp;
     QUrl mTempFile;
-    QTemporaryDir *mTempDir;
+    QTemporaryDir *mTempDir = nullptr;
     QList<QUrl> mUsedTempFileNames;
     QString mWindowTitle;
-    Spectacle::CaptureMode mCaptureMode { Spectacle::CaptureMode::AllScreens };
+    Spectacle::CaptureMode mCaptureMode{Spectacle::CaptureMode::AllScreens};
 };
