@@ -1,21 +1,5 @@
 /* This file is part of Spectacle, the KDE screenshot utility
- * Copyright (C) 2015 Boudhayan Gupta <bgupta@kde.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
+ * SPDX-FileCopyrightText: 2015 Boudhayan Gupta <bgupta@kde.org>
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
@@ -24,9 +8,9 @@
 #include <QGuiApplication>
 #include <QStyleHints>
 
-KSImageWidget::KSImageWidget(QWidget *parent):
-    QLabel(parent),
-    mPixmap(QPixmap())
+KSImageWidget::KSImageWidget(QWidget *parent)
+    : QLabel(parent)
+    , mPixmap(QPixmap())
 {
     mDSEffect = new QGraphicsDropShadowEffect(this);
 
@@ -55,6 +39,11 @@ void KSImageWidget::setScaledPixmap()
     setPixmap(scaledPixmap);
 }
 
+bool KSImageWidget::isPixmapSet()
+{
+    return !mPixmap.isNull();
+}
+
 // drag handlers
 
 void KSImageWidget::mousePressEvent(QMouseEvent *event)
@@ -83,7 +72,7 @@ void KSImageWidget::mouseMoveEvent(QMouseEvent *event)
     }
 
     setCursor(Qt::OpenHandCursor);
-    emit dragInitiated();
+    Q_EMIT dragInitiated();
 }
 
 // resize handler
@@ -93,4 +82,3 @@ void KSImageWidget::resizeEvent(QResizeEvent *event)
     Q_UNUSED(event)
     setScaledPixmap();
 }
-
