@@ -1,31 +1,18 @@
 /*
- *  Copyright 2019 David Redondo <kde@david-redondo.de>
- *  Copyright (C) 2015 Boudhayan Gupta <bgupta@kde.org>
+ *  SPDX-FileCopyrightText: 2019 David Redondo <kde@david-redondo.de>
+ *  SPDX-FileCopyrightText: 2015 Boudhayan Gupta <bgupta@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Lesser General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "KSWidget.h"
 #include "spectacle_gui_debug.h"
 
-#include "KSImageWidget.h"
-#include "settings.h"
-#include "SmartSpinBox.h"
-#include "ProgressButton.h"
 #include "ExportManager.h"
+#include "KSImageWidget.h"
+#include "ProgressButton.h"
+#include "SmartSpinBox.h"
+#include "settings.h"
 
 #include <QAction>
 #include <QApplication>
@@ -57,6 +44,7 @@ KSWidget::KSWidget(Platform::GrabModes theGrabModes, QWidget *parent)
 #ifdef KIMAGEANNOTATOR_FOUND
     mAnnotator = new kImageAnnotator::KImageAnnotator();
     mAnnotator->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+    mAnnotator->setCanvasColor(QColor(255, 255, 255, 0));
     mStack->addWidget(mAnnotator);
 #endif
 
@@ -65,14 +53,11 @@ KSWidget::KSWidget(Platform::GrabModes theGrabModes, QWidget *parent)
     mCaptureArea = new QComboBox(this);
 
     if (theGrabModes.testFlag(Platform::GrabMode::AllScreens)) {
-
-        QString lFullScreenLabel = QApplication::screens().count() == 1
-                ? i18n("Full Screen")
-                : i18n("Full Screen (All Monitors)");
+        QString lFullScreenLabel = QApplication::screens().count() == 1 ? i18n("Full Screen") : i18n("Full Screen (All Monitors)");
 
         mCaptureArea->insertItem(0, lFullScreenLabel, Spectacle::CaptureMode::AllScreens);
     }
-    if (theGrabModes.testFlag(Platform::GrabMode::AllScreensScaled) &&  QApplication::screens().count() > 1) {
+    if (theGrabModes.testFlag(Platform::GrabMode::AllScreensScaled) && QApplication::screens().count() > 1) {
         QString lFullScreenLabel = i18n("Full Screen (All Monitors, scaled)");
         mCaptureArea->insertItem(1, lFullScreenLabel, Spectacle::CaptureMode::AllScreensScaled);
     }
@@ -133,8 +118,9 @@ KSWidget::KSWidget(Platform::GrabModes theGrabModes, QWidget *parent)
     mWindowDecorations->setObjectName(QStringLiteral("kcfg_includeDecorations"));
 
     mCaptureTransientOnly = new QCheckBox(i18n("Capture the current pop-up only"), this);
-    mCaptureTransientOnly->setToolTip(i18n("Capture only the current pop-up window (like a menu, tooltip etc).\n"
-                                           "If disabled, the pop-up is captured along with the parent window"));
+    mCaptureTransientOnly->setToolTip(
+        i18n("Capture only the current pop-up window (like a menu, tooltip etc).\n"
+             "If disabled, the pop-up is captured along with the parent window"));
     mCaptureTransientOnly->setEnabled(false);
     mCaptureTransientOnly->setObjectName(QStringLiteral("kcfg_transientOnly"));
 
@@ -156,7 +142,7 @@ KSWidget::KSWidget(Platform::GrabModes theGrabModes, QWidget *parent)
     mCancelAction = new QAction(QIcon::fromTheme(QStringLiteral("dialog-cancel")), i18n("Cancel"), this);
     mCancelAction->setShortcut(QKeySequence::Cancel);
     connect(mCancelAction, &QAction::triggered, this, [this] {
-        emit screenshotCanceled();
+        Q_EMIT screenshotCanceled();
         setButtonState(State::TakeNewScreenshot);
     });
 
@@ -179,8 +165,24 @@ KSWidget::KSWidget(Platform::GrabModes theGrabModes, QWidget *parent)
     mRightLayout->addWidget(mTakeScreenshotButton, 1, Qt::AlignHCenter);
     mRightLayout->setContentsMargins(10, 0, 0, 10);
 
+    mPlaceholderLabel = new QLabel;
+
+    QFont placeholderLabelFont;
+    // To match the size of a level 2 Heading/KTitleWidget
+    placeholderLabelFont.setPointSize(qRound(placeholderLabelFont.pointSize() * 1.3));
+    mPlaceholderLabel->setFont(placeholderLabelFont);
+    mPlaceholderLabel->setTextInteractionFlags(Qt::NoTextInteraction);
+    mPlaceholderLabel->setWordWrap(true);
+    mPlaceholderLabel->setAlignment(Qt::AlignCenter);
+    mPlaceholderLabel->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+    // Match opacity of QML placeholder label component
+    auto *effect = new QGraphicsOpacityEffect(mPlaceholderLabel);
+    effect->setOpacity(0.5);
+    mPlaceholderLabel->setGraphicsEffect(effect);
+
     mMainLayout = new QGridLayout();
 
+    mMainLayout->addWidget(mPlaceholderLabel, 0, 0, 1, 1);
     mMainLayout->addWidget(mImageWidget, 0, 0, 1, 1);
     mMainLayout->addLayout(mRightLayout, 0, 1, 1, 1);
     mMainLayout->setColumnMinimumWidth(0, 320);
@@ -203,9 +205,9 @@ KSWidget::KSWidget(Platform::GrabModes theGrabModes, QWidget *parent)
 
 int KSWidget::imagePaddingWidth() const
 {
-    int lRightLayoutLeft  = 0;
+    int lRightLayoutLeft = 0;
     int lRightLayoutRight = 0;
-    int lMainLayoutRight  = 0;
+    int lMainLayoutRight = 0;
 
     mRightLayout->getContentsMargins(&lRightLayoutLeft, nullptr, &lRightLayoutRight, nullptr);
     mMainLayout->getContentsMargins(nullptr, nullptr, &lMainLayoutRight, nullptr);
@@ -217,10 +219,26 @@ int KSWidget::imagePaddingWidth() const
     return lPaddingWidth;
 }
 
+bool KSWidget::isScreenshotSet()
+{
+    return mImageWidget->isPixmapSet();
+}
+
 // public slots
 
+void KSWidget::showPlaceholderText(const QString &label)
+{
+    mImageWidget->hide();
+    mPlaceholderLabel->setText(label);
+    mPlaceholderLabel->show();
+}
+
 void KSWidget::setScreenshotPixmap(const QPixmap &thePixmap)
 {
+    if (mPlaceholderLabel->isVisible()) {
+        mPlaceholderLabel->hide();
+    }
+    mImageWidget->show();
     mImageWidget->setScreenshot(thePixmap);
 }
 
@@ -233,6 +251,7 @@ void KSWidget::lockOnClickEnabled()
 
 void KSWidget::lockOnClickDisabled()
 {
+    mCaptureOnClick->setCheckState(Qt::Unchecked);
     mCaptureOnClick->hide();
     mDelayMsec->setEnabled(true);
 }
@@ -243,13 +262,11 @@ void KSWidget::newScreenshotClicked()
 {
     int lDelay = mCaptureOnClick->isChecked() ? -1 : (mDelayMsec->value() * 1000);
     auto lMode = static_cast<Spectacle::CaptureMode>(mCaptureArea->currentData().toInt());
-    if (mTransientWithParentAvailable &&
-        lMode == Spectacle::CaptureMode::WindowUnderCursor &&
-        !(mCaptureTransientOnly->isChecked())) {
+    if (mTransientWithParentAvailable && lMode == Spectacle::CaptureMode::WindowUnderCursor && !(mCaptureTransientOnly->isChecked())) {
         lMode = Spectacle::CaptureMode::TransientWithParent;
     }
     setButtonState(State::Cancel);
-    emit newScreenshotRequest(lMode, lDelay, mMousePointer->isChecked(), mWindowDecorations->isChecked());
+    Q_EMIT newScreenshotRequest(lMode, lDelay, mMousePointer->isChecked(), mWindowDecorations->isChecked());
 }
 
 void KSWidget::onClickStateChanged(int theState)
@@ -264,7 +281,7 @@ void KSWidget::onClickStateChanged(int theState)
 void KSWidget::captureModeChanged(int theIndex)
 {
     Spectacle::CaptureMode captureMode = static_cast<Spectacle::CaptureMode>(mCaptureArea->itemData(theIndex).toInt());
-    switch(captureMode) {
+    switch (captureMode) {
     case Spectacle::CaptureMode::WindowUnderCursor:
         mWindowDecorations->setEnabled(true);
         if (mTransientWithParentAvailable) {
