@@ -1,19 +1,7 @@
 /*
- * Copyright (C) 2019  David Redondo <kde@david-redondo.de>
+ * SPDX-FileCopyrightText: 2019 David Redondo <kde@david-redondo.de>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "ShortcutsOptionsPage.h"
@@ -25,7 +13,8 @@
 
 #include <QVBoxLayout>
 
-ShortcutsOptionsPage::ShortcutsOptionsPage(QWidget* parent) : QWidget(parent)
+ShortcutsOptionsPage::ShortcutsOptionsPage(QWidget *parent)
+    : QWidget(parent)
 {
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     setLayout(mainLayout);
@@ -43,7 +32,6 @@ ShortcutsOptionsPage::~ShortcutsOptionsPage()
 #endif
 }
 
-
 void ShortcutsOptionsPage::resetChanges()
 {
 #if KXMLGUI_VERSION >= QT_VERSION_CHECK(5, 75, 0)
@@ -58,14 +46,12 @@ void ShortcutsOptionsPage::saveChanges()
     mEditor->commit();
 }
 
-bool ShortcutsOptionsPage::isModified()
+bool ShortcutsOptionsPage::isModified() const
 {
     return mEditor->isModified();
 }
 
-void ShortcutsOptionsPage::defaults()
+void ShortcutsOptionsPage::defaults() const
 {
     mEditor->allDefault();
 }
-
-
