@@ -1,41 +1,28 @@
 /*
- *  Copyright (C) 2015 Boudhayan Gupta <me@BaloneyGeek.com>
- *  Copyright 2010 Pau Garcia i Quiles <pgquiles@elpauer.org>
+ *  SPDX-FileCopyrightText: 2015 Boudhayan Gupta <me@BaloneyGeek.com>
+ *  SPDX-FileCopyrightText: 2010 Pau Garcia i Quiles <pgquiles@elpauer.org>
  *  based on code for Gwenview by
- *  Copyright 2008 Aurélien Gâteau <agateau@kde.org>
+ *  SPDX-FileCopyrightText: 2008 Aurélien Gâteau <agateau@kde.org>
  *
- *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU General Public License
- *  as published by the Free Software Foundation; either version 2
- *  of the License, or (at your option) any later version.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA.
- *
-*/
+ */
 
 #include "KSGKipiImageCollectionSelector.h"
 #include <KLocalizedString>
 #include <QVBoxLayout>
 
 KSGKipiImageCollectionSelector::KSGKipiImageCollectionSelector(KIPI::Interface *interface, QWidget *parent)
-    : KIPI::ImageCollectionSelector(parent),
-      mInterface(interface),
-      mListWidget(new QListWidget)
+    : KIPI::ImageCollectionSelector(parent)
+    , mInterface(interface)
+    , mListWidget(new QListWidget(this))
 {
     const auto allAlbums = interface->allAlbums();
     for (const auto &collection : allAlbums) {
         QListWidgetItem *item = new QListWidgetItem(mListWidget);
         QString name = collection.name();
         int imageCount = collection.images().size();
-        QString title = i18ncp("%1 is collection name, %2 is image count in collection",
-                               "%1 (%2 image)", "%1 (%2 images)", name, imageCount);
+        QString title = i18ncp("%1 is collection name, %2 is image count in collection", "%1 (%2 image)", "%1 (%2 images)", name, imageCount);
         item->setText(title);
         item->setData(Qt::UserRole, name);
     }
@@ -47,7 +34,8 @@ KSGKipiImageCollectionSelector::KSGKipiImageCollectionSelector(KIPI::Interface *
 }
 
 KSGKipiImageCollectionSelector::~KSGKipiImageCollectionSelector()
-{}
+{
+}
 
 QList<KIPI::ImageCollection> KSGKipiImageCollectionSelector::selectedImageCollections() const
 {
@@ -66,5 +54,3 @@ QList<KIPI::ImageCollection> KSGKipiImageCollectionSelector::selectedImageCollec
     }
     return selectedList;
 }
-
-
