@@ -1,35 +1,22 @@
 /*
- *  Copyright 2019 David Redondo <kde@david-redondo.de>
- *  Copyright (C) 2015 Boudhayan Gupta <bgupta@kde.org>
+ *  SPDX-FileCopyrightText: 2019 David Redondo <kde@david-redondo.de>
+ *  SPDX-FileCopyrightText: 2015 Boudhayan Gupta <bgupta@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Lesser General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "SpectacleCore.h"
 #include "spectacle_core_debug.h"
 
 #include "Config.h"
-#include "settings.h"
 #include "ShortcutActions.h"
+#include "settings.h"
 
 #include <KGlobalAccel>
+#include <KIO/OpenUrlJob>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KNotification>
-#include <KRun>
 #include <KWayland/Client/connection_thread.h>
 #include <KWayland/Client/plasmashell.h>
 #include <KWayland/Client/registry.h>
@@ -41,17 +28,14 @@
 #include <QDrag>
 #include <QKeySequence>
 #include <QMimeData>
-#include <QProcess>
-#include <QTimer>
-#include <QScopedPointer>
 #include <QPainter>
+#include <QProcess>
+#include <QScopedPointer>
 #include <QScreen>
+#include <QTimer>
 
-SpectacleCore::SpectacleCore(QObject *parent):
-    QObject(parent),
-    mMainWindow(nullptr),
-    mIsGuiInited(false),
-    mWaylandPlasmashell(nullptr)
+SpectacleCore::SpectacleCore(QObject *parent)
+    : QObject(parent)
 {
 }
 
@@ -81,18 +65,16 @@ void SpectacleCore::init()
         }
         Registry *registry = new Registry(this);
         registry->create(connection);
-        connect(registry, &Registry::plasmaShellAnnounced, this,
-            [this, registry] (quint32 name, quint32 version) {
-                mWaylandPlasmashell = registry->createPlasmaShell(name, version, this);
-            }
-        );
+        connect(registry, &Registry::plasmaShellAnnounced, this, [this, registry](quint32 name, quint32 version) {
+            mWaylandPlasmashell = registry->createPlasmaShell(name, version, this);
+        });
         registry->setup();
         connection->roundtrip();
     }
     setUpShortcuts();
 }
 
-void SpectacleCore::onActivateRequested(QStringList arguments, const QString& /*workingDirectory */)
+void SpectacleCore::onActivateRequested(QStringList arguments, const QString & /*workingDirectory */)
 {
     // QCommandLineParser expects the first argument to be the executable name
     // In the current version it just strips it away
@@ -103,20 +85,6 @@ void SpectacleCore::onActivateRequested(QStringList arguments, const QString& /*
     populateCommandLineParser(parser.data());
     parser->parse(arguments);
 
-    // extract the capture mode
-    Spectacle::CaptureMode lCaptureMode = Spectacle::CaptureMode::AllScreens;
-    if (parser->isSet(QStringLiteral("current"))) {
-        lCaptureMode = Spectacle::CaptureMode::CurrentScreen;
-    } else if (parser->isSet(QStringLiteral("activewindow"))) {
-        lCaptureMode = Spectacle::CaptureMode::ActiveWindow;
-    } else if (parser->isSet(QStringLiteral("region"))) {
-        lCaptureMode = Spectacle::CaptureMode::RectangularRegion;
-    } else if (parser->isSet(QStringLiteral("windowundercursor"))) {
-        lCaptureMode = Spectacle::CaptureMode::TransientWithParent;
-    } else if (parser->isSet(QStringLiteral("transientonly"))) {
-        lCaptureMode = Spectacle::CaptureMode::WindowUnderCursor;
-    }
-
     mStartMode = SpectacleCore::StartMode::Gui;
     mNotify = true;
     qint64 lDelayMsec = 0;
@@ -128,29 +96,57 @@ void SpectacleCore::onActivateRequested(QStringList arguments, const QString& /*
         mStartMode = SpectacleCore::StartMode::DBus;
     }
 
-    auto lExportManager = ExportManager::instance();
-    lExportManager->setCaptureMode(lCaptureMode);
-
     auto lOnClickAvailable = mPlatform->supportedShutterModes().testFlag(Platform::ShutterMode::OnClick);
     if ((!lOnClickAvailable) && (lDelayMsec < 0)) {
         lDelayMsec = 0;
     }
 
     // reset last region if it should not be remembered across restarts
-    if(!Settings::alwaysRememberRegion()) {
+    if (!(Settings::rememberLastRectangularRegion() == Settings::EnumRememberLastRectangularRegion::Always)) {
         Settings::setCropRegion({0, 0, 0, 0});
     }
 
-    switch (mStartMode) {
+    Spectacle::CaptureMode lCaptureMode = Spectacle::CaptureMode::AllScreens;
+    // extract the capture mode
+    if (parser->isSet(QStringLiteral("fullscreen"))) {
+        lCaptureMode = Spectacle::CaptureMode::AllScreens;
+    } else if (parser->isSet(QStringLiteral("current"))) {
+        lCaptureMode = Spectacle::CaptureMode::CurrentScreen;
+    } else if (parser->isSet(QStringLiteral("activewindow"))) {
+        lCaptureMode = Spectacle::CaptureMode::ActiveWindow;
+    } else if (parser->isSet(QStringLiteral("region"))) {
+        lCaptureMode = Spectacle::CaptureMode::RectangularRegion;
+    } else if (parser->isSet(QStringLiteral("windowundercursor"))) {
+        lCaptureMode = Spectacle::CaptureMode::TransientWithParent;
+    } else if (parser->isSet(QStringLiteral("transientonly"))) {
+        lCaptureMode = Spectacle::CaptureMode::WindowUnderCursor;
+    } else if (mStartMode == SpectacleCore::StartMode::Gui
+               && (parser->isSet(QStringLiteral("launchonly")) || Settings::onLaunchAction() == Settings::EnumOnLaunchAction::DoNotTakeScreenshot)) {
+        initGuiNoScreenshot();
+        return;
+    } else if (Settings::onLaunchAction() == Settings::EnumOnLaunchAction::UseLastUsedCapturemode) {
+        lCaptureMode = Settings::captureMode();
+        if (Settings::onClickChecked()) {
+            lDelayMsec = -1;
+            takeNewScreenshot(lCaptureMode, lDelayMsec, Settings::includePointer(), Settings::includeDecorations());
+        }
+    }
 
+    auto lExportManager = ExportManager::instance();
+    lExportManager->setCaptureMode(lCaptureMode);
+
+    switch (mStartMode) {
     case StartMode::DBus:
-        mCopyToClipboard = Settings::copyImageToClipboard();
+        mCopyImageToClipboard = Settings::clipboardGroup() == Settings::EnumClipboardGroup::PostScreenshotCopyImage;
+        mCopyLocationToClipboard = Settings::clipboardGroup() == Settings::EnumClipboardGroup::PostScreenshotCopyLocation;
+
         qApp->setQuitOnLastWindowClosed(false);
-        mCopyToClipboard = Settings::copyImageToClipboard();
         break;
 
     case StartMode::Background: {
-        mCopyToClipboard = false;
+        mCopyImageToClipboard = false;
+        mCopyLocationToClipboard = false;
+
         if (parser->isSet(QStringLiteral("nonotify"))) {
             mNotify = false;
         }
@@ -178,8 +174,10 @@ void SpectacleCore::onActivateRequested(QStringList arguments, const QString& /*
             lDelayMsec = -1;
         }
 
-        if (parser->isSet(QStringLiteral("clipboard"))) {
-            mCopyToClipboard = true;
+        if (parser->isSet(QStringLiteral("copy-image"))) {
+            mCopyImageToClipboard = true;
+        } else if (parser->isSet(QStringLiteral("copy-path"))) {
+            mCopyLocationToClipboard = true;
         }
 
         if (!mIsGuiInited) {
@@ -198,8 +196,7 @@ void SpectacleCore::onActivateRequested(QStringList arguments, const QString& /*
         }
 
         takeNewScreenshot(lCaptureMode, lDelayMsec, lIncludePointer, lIncludeDecorations);
-    }
-        break;
+    } break;
 
     case StartMode::Gui:
         if (!mIsGuiInited) {
@@ -207,27 +204,27 @@ void SpectacleCore::onActivateRequested(QStringList arguments, const QString& /*
         } else {
             using Actions = Settings::EnumPrintKeyActionRunning;
             switch (Settings::printKeyActionRunning()) {
-                case Actions::TakeNewScreenshot: {
-                    // 0 means Immediate, -1 onClick
-                    int timeout = mPlatform->supportedShutterModes().testFlag(Platform::ShutterMode::Immediate) ? 0 : -1;
-                    takeNewScreenshot(Settings::captureMode(), timeout, Settings::includePointer(), Settings::includeDecorations());
-                    break;
+            case Actions::TakeNewScreenshot: {
+                // 0 means Immediate, -1 onClick
+                int timeout = mPlatform->supportedShutterModes().testFlag(Platform::ShutterMode::Immediate) ? 0 : -1;
+                takeNewScreenshot(Settings::captureMode(), timeout, Settings::includePointer(), Settings::includeDecorations());
+                break;
+            }
+            case Actions::FocusWindow:
+                if (mMainWindow->isHidden()) {
+                    mMainWindow->show();
                 }
-                case Actions::FocusWindow:
-                    if (mMainWindow->isHidden()) {
-                        mMainWindow->show();
-                    }
-                    if (mMainWindow->isMinimized()) {
-                        mMainWindow->setWindowState(mMainWindow->windowState() & ~Qt::WindowMinimized);
-                    }
-                    mMainWindow->activateWindow();
-                    break;
-                case Actions::StartNewInstance:
-                    QProcess newInstance;
-                    newInstance.setProgram(QStringLiteral("spectacle"));
-                    newInstance.setArguments({QStringLiteral("--new-instance")});
-                    newInstance.startDetached();
-                    break;
+                if (mMainWindow->isMinimized()) {
+                    mMainWindow->setWindowState(mMainWindow->windowState() & ~Qt::WindowMinimized);
+                }
+                mMainWindow->activateWindow();
+                break;
+            case Actions::StartNewInstance:
+                QProcess newInstance;
+                newInstance.setProgram(QStringLiteral("spectacle"));
+                newInstance.setArguments({QStringLiteral("--new-instance")});
+                newInstance.startDetached();
+                break;
             }
         }
 
@@ -239,13 +236,17 @@ void SpectacleCore::setUpShortcuts()
 {
     KGlobalAccel::self()->setGlobalShortcut(ShortcutActions::self()->openAction(), Qt::Key_Print);
 
-    KGlobalAccel::self()->setGlobalShortcut(ShortcutActions::self()->fullScreenAction(), Qt::SHIFT + Qt::Key_Print);
+    KGlobalAccel::self()->setGlobalShortcut(ShortcutActions::self()->fullScreenAction(), Qt::SHIFT | Qt::Key_Print);
 
-    KGlobalAccel::self()->setGlobalShortcut(ShortcutActions::self()->activeWindowAction(), Qt::META + Qt::Key_Print);
+    KGlobalAccel::self()->setGlobalShortcut(ShortcutActions::self()->activeWindowAction(), Qt::META | Qt::Key_Print);
 
-    KGlobalAccel::self()->setGlobalShortcut(ShortcutActions::self()->regionAction(), Qt::META + Qt::SHIFT + Qt::Key_Print);
+    KGlobalAccel::self()->setGlobalShortcut(ShortcutActions::self()->windowUnderCursorAction(), Qt::META | Qt::CTRL | Qt::Key_Print);
+
+    KGlobalAccel::self()->setGlobalShortcut(ShortcutActions::self()->regionAction(), Qt::META | Qt::SHIFT | Qt::Key_Print);
 
     KGlobalAccel::self()->setGlobalShortcut(ShortcutActions::self()->currentScreenAction(), QList<QKeySequence>());
+
+    KGlobalAccel::self()->setGlobalShortcut(ShortcutActions::self()->openWithoutScreenshotAction(), QList<QKeySequence>());
 }
 
 QString SpectacleCore::filename() const
@@ -259,10 +260,7 @@ void SpectacleCore::setFilename(const QString &filename)
     mFileNameUrl = QUrl::fromUserInput(filename);
 }
 
-void SpectacleCore::takeNewScreenshot(Spectacle::CaptureMode theCaptureMode,
-                                      int  theTimeout,
-                                      bool theIncludePointer,
-                                      bool theIncludeDecorations)
+void SpectacleCore::takeNewScreenshot(Spectacle::CaptureMode theCaptureMode, int theTimeout, bool theIncludePointer, bool theIncludeDecorations)
 {
     ExportManager::instance()->setCaptureMode(theCaptureMode);
     auto lGrabMode = toPlatformGrabMode(theCaptureMode);
@@ -295,21 +293,18 @@ void SpectacleCore::showErrorMessage(const QString &theErrString)
 
 void SpectacleCore::screenshotsUpdated(const QVector<QImage> &imgs)
 {
-    QMap<ComparableQPoint, QImage> mapScreens;
+    QMap<const QScreen *, QImage> mapScreens;
     QList<QScreen *> screens = QGuiApplication::screens();
 
     if (imgs.length() != screens.size()) {
         qWarning(SPECTACLE_CORE_LOG()) << "ERROR: images received from KWin do not match, expected:" << imgs.length() << "actual:" << screens.size();
-        return ;
+        return;
     }
 
     // only used by Spectacle::CaptureMode::RectangularRegion
     auto it = imgs.constBegin();
-    for (const QScreen *screen: screens) {
-        auto pos = screen->geometry().topLeft();
-        auto img = *it;
-        auto dpr = img.width() / static_cast<qreal>(screen->geometry().width());
-        mapScreens.insert(pos, img);
+    for (const QScreen *screen : screens) {
+        mapScreens.insert(screen, *it);
         ++it;
     }
 
@@ -335,38 +330,43 @@ void SpectacleCore::screenshotUpdated(const QPixmap &thePixmap)
 
     switch (mStartMode) {
     case StartMode::Background:
-    case StartMode::DBus:
-        {
-            if (mSaveToOutput || !mCopyToClipboard || (Settings::autoSaveImage() && !mSaveToOutput)) {
-                mSaveToOutput = Settings::autoSaveImage();
-                QUrl lSavePath = (mStartMode == StartMode::Background && mFileNameUrl.isValid() && mFileNameUrl.isLocalFile()) ?
-                    mFileNameUrl : QUrl();
-                lExportManager->doSave(lSavePath, mNotify);
-            }
+    case StartMode::DBus: {
+        if (mSaveToOutput || !mCopyImageToClipboard || (Settings::autoSaveImage() && !mSaveToOutput)) {
+            mSaveToOutput = Settings::autoSaveImage();
+            QUrl lSavePath = (mStartMode == StartMode::Background && mFileNameUrl.isValid() && mFileNameUrl.isLocalFile()) ? mFileNameUrl : QUrl();
+            lExportManager->doSave(lSavePath, mNotify);
+        }
 
-            if (mCopyToClipboard) {
-                lExportManager->doCopyToClipboard(mNotify);
-            }
+        if (mCopyImageToClipboard) {
+            lExportManager->doCopyToClipboard(mNotify);
+        } else if (mCopyLocationToClipboard) {
+            lExportManager->doCopyLocationToClipboard(mNotify);
+        }
 
-            // if we don't have a Gui already opened, emit allDone
-            if (!this->mIsGuiInited) {
-                // if we notify, we emit allDone only if the user either dismissed the notification or pressed
-                // the "Open" button, otherwise the app closes before it can react to it.
-                if (!mNotify && mCopyToClipboard) {
-                    // Allow some time for clipboard content to transfer if '--nonotify' is used, see Bug #411263
-                    // TODO: Find better solution
-                    QTimer::singleShot(250, this, &SpectacleCore::allDone);
-                } else if (!mNotify) {
-                    emit allDone();
-                }
+        // if we don't have a Gui already opened, Q_EMIT allDone
+        if (!mIsGuiInited) {
+            // if we notify, we Q_EMIT allDone only if the user either dismissed the notification or pressed
+            // the "Open" button, otherwise the app closes before it can react to it.
+            if (!mNotify && mCopyImageToClipboard) {
+                // Allow some time for clipboard content to transfer if '--nonotify' is used, see Bug #411263
+                // TODO: Find better solution
+                QTimer::singleShot(250, this, &SpectacleCore::allDone);
+            } else if (!mNotify) {
+                Q_EMIT allDone();
             }
         }
-        break;
+    } break;
     case StartMode::Gui:
+        if (thePixmap.isNull()) {
+            mMainWindow->setScreenshotAndShow(thePixmap);
+            mMainWindow->setPlaceholderTextOnLaunch();
+            return;
+        }
         mMainWindow->setScreenshotAndShow(thePixmap);
 
         bool autoSaveImage = Settings::autoSaveImage();
-        bool mCopyImageToClipboard = Settings::copyImageToClipboard();
+        mCopyImageToClipboard = Settings::clipboardGroup() == Settings::EnumClipboardGroup::PostScreenshotCopyImage;
+        mCopyLocationToClipboard = Settings::clipboardGroup() == Settings::EnumClipboardGroup::PostScreenshotCopyLocation;
 
         if (autoSaveImage && mCopyImageToClipboard) {
             lExportManager->doSaveAndCopy();
@@ -374,6 +374,8 @@ void SpectacleCore::screenshotUpdated(const QPixmap &thePixmap)
             lExportManager->doSave();
         } else if (mCopyImageToClipboard) {
             lExportManager->doCopyToClipboard(false);
+        } else if (mCopyLocationToClipboard) {
+            lExportManager->doCopyLocationToClipboard(false);
         }
     }
 }
@@ -385,7 +387,7 @@ void SpectacleCore::screenshotCanceled()
     if (mStartMode == StartMode::Gui) {
         mMainWindow->setScreenshotAndShow(QPixmap());
     } else {
-        emit allDone();
+        Q_EMIT allDone();
     }
 }
 
@@ -399,11 +401,11 @@ void SpectacleCore::screenshotFailed()
     switch (mStartMode) {
     case StartMode::Background:
         showErrorMessage(i18n("Screenshot capture canceled or failed"));
-        emit allDone();
+        Q_EMIT allDone();
         return;
     case StartMode::DBus:
-        emit grabFailed();
-        emit allDone();
+        Q_EMIT grabFailed();
+        Q_EMIT allDone();
         return;
     case StartMode::Gui:
         mMainWindow->screenshotFailed();
@@ -415,7 +417,7 @@ void SpectacleCore::doNotify(const QUrl &theSavedAt)
 {
     KNotification *lNotify = new KNotification(QStringLiteral("newScreenshotSaved"));
 
-    switch(ExportManager::instance()->captureMode()) {
+    switch (ExportManager::instance()->captureMode()) {
     case Spectacle::CaptureMode::AllScreens:
     case Spectacle::CaptureMode::AllScreensScaled:
         lNotify->setTitle(i18nc("The entire screen area was captured, heading", "Full Screen Captured"));
@@ -439,11 +441,14 @@ void SpectacleCore::doNotify(const QUrl &theSavedAt)
 
     // a speaking message is prettier than a URL, special case for copy to clipboard and the default pictures location
     const QString &lSavePath = theSavedAt.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash).path();
-    if (mSaveToOutput) {
+
+    static bool isBackgroundMode = (mStartMode == SpectacleCore::StartMode::Background);
+
+    if (mSaveToOutput || isBackgroundMode) {
         lNotify->setText(i18n("A screenshot was saved as '%1' to '%2'.", theSavedAt.fileName(), lSavePath));
         // set to false so it won't show the same message twice
-        mSaveToOutput = false;
-    } else if (mCopyToClipboard) {
+        isBackgroundMode = false;
+    } else if (mCopyImageToClipboard) {
         lNotify->setText(i18n("A screenshot was saved to your clipboard."));
     } else if (lSavePath == QStandardPaths::writableLocation(QStandardPaths::PicturesLocation)) {
         lNotify->setText(i18nc("Placeholder is filename", "A screenshot was saved as '%1' to your Pictures folder.", theSavedAt.fileName()));
@@ -456,10 +461,11 @@ void SpectacleCore::doNotify(const QUrl &theSavedAt)
         lNotify->setDefaultAction(i18nc("Open the screenshot we just saved", "Open"));
         connect(lNotify, QOverload<uint>::of(&KNotification::activated), this, [this, theSavedAt](uint index) {
             if (index == 0) {
-                new KRun(theSavedAt, nullptr);
+                auto job = new KIO::OpenUrlJob(theSavedAt);
+                job->start();
                 QTimer::singleShot(250, this, [this] {
                     if (!mIsGuiInited || Settings::quitAfterSaveCopyExport()) {
-                        emit allDone();
+                        Q_EMIT allDone();
                     }
                 });
             }
@@ -468,7 +474,7 @@ void SpectacleCore::doNotify(const QUrl &theSavedAt)
 
     connect(lNotify, &QObject::destroyed, this, [this] {
         if (!mIsGuiInited || Settings::quitAfterSaveCopyExport()) {
-            emit allDone();
+            Q_EMIT allDone();
         }
     });
 
@@ -477,7 +483,7 @@ void SpectacleCore::doNotify(const QUrl &theSavedAt)
 
 void SpectacleCore::doCopyPath(const QUrl &savedAt)
 {
-    if (Settings::copySaveLocation()) {
+    if (Settings::clipboardGroup() == Settings::EnumClipboardGroup::PostScreenshotCopyLocation) {
         qApp->clipboard()->setText(savedAt.toLocalFile());
     }
 }
@@ -485,41 +491,48 @@ void SpectacleCore::doCopyPath(const QUrl &savedAt)
 void SpectacleCore::populateCommandLineParser(QCommandLineParser *lCmdLineParser)
 {
     lCmdLineParser->addOptions({
-        {{QStringLiteral("f"), QStringLiteral("fullscreen")},        i18n("Capture the entire desktop (default)")},
-        {{QStringLiteral("m"), QStringLiteral("current")},           i18n("Capture the current monitor")},
-        {{QStringLiteral("a"), QStringLiteral("activewindow")},      i18n("Capture the active window")},
+        {{QStringLiteral("f"), QStringLiteral("fullscreen")}, i18n("Capture the entire desktop (default)")},
+        {{QStringLiteral("m"), QStringLiteral("current")}, i18n("Capture the current monitor")},
+        {{QStringLiteral("a"), QStringLiteral("activewindow")}, i18n("Capture the active window")},
         {{QStringLiteral("u"), QStringLiteral("windowundercursor")}, i18n("Capture the window currently under the cursor, including parents of pop-up menus")},
-        {{QStringLiteral("t"), QStringLiteral("transientonly")},     i18n("Capture the window currently under the cursor, excluding parents of pop-up menus")},
-        {{QStringLiteral("r"), QStringLiteral("region")},            i18n("Capture a rectangular region of the screen")},
-        {{QStringLiteral("g"), QStringLiteral("gui")},               i18n("Start in GUI mode (default)")},
-        {{QStringLiteral("b"), QStringLiteral("background")},        i18n("Take a screenshot and exit without showing the GUI")},
-        {{QStringLiteral("s"), QStringLiteral("dbus")},              i18n("Start in DBus-Activation mode")},
-        {{QStringLiteral("n"), QStringLiteral("nonotify")},          i18n("In background mode, do not pop up a notification when the screenshot is taken")},
-        {{QStringLiteral("o"), QStringLiteral("output")},            i18n("In background mode, save image to specified file"), QStringLiteral("fileName")},
-        {{QStringLiteral("d"), QStringLiteral("delay")},             i18n("In background mode, delay before taking the shot (in milliseconds)"), QStringLiteral("delayMsec")},
-        {{QStringLiteral("c"), QStringLiteral("clipboard")},         i18n("In background mode, copy screenshot to clipboard")},
-        {{QStringLiteral("w"), QStringLiteral("onclick")},           i18n("Wait for a click before taking screenshot. Invalidates delay")},
-        {{QStringLiteral("i"), QStringLiteral("new-instance")},      i18n("Starts a new GUI instance of spectacle without registering to DBus")},
-        {{QStringLiteral("p"), QStringLiteral("pointer")},           i18n("In background mode, include pointer in the screenshot")},
-        {{QStringLiteral("e"),QStringLiteral("no-decoration")},     i18n("In background mode, exclude decorations in the screenshot")},
+        {{QStringLiteral("t"), QStringLiteral("transientonly")}, i18n("Capture the window currently under the cursor, excluding parents of pop-up menus")},
+        {{QStringLiteral("r"), QStringLiteral("region")}, i18n("Capture a rectangular region of the screen")},
+        {{QStringLiteral("l"), QStringLiteral("launchonly")}, i18n("Launch Spectacle without taking a screenshot")},
+        {{QStringLiteral("g"), QStringLiteral("gui")}, i18n("Start in GUI mode (default)")},
+        {{QStringLiteral("b"), QStringLiteral("background")}, i18n("Take a screenshot and exit without showing the GUI")},
+        {{QStringLiteral("s"), QStringLiteral("dbus")}, i18n("Start in DBus-Activation mode")},
+        {{QStringLiteral("n"), QStringLiteral("nonotify")}, i18n("In background mode, do not pop up a notification when the screenshot is taken")},
+        {{QStringLiteral("o"), QStringLiteral("output")}, i18n("In background mode, save image to specified file"), QStringLiteral("fileName")},
+        {{QStringLiteral("d"), QStringLiteral("delay")},
+         i18n("In background mode, delay before taking the shot (in milliseconds)"),
+         QStringLiteral("delayMsec")},
+        {{QStringLiteral("c"), QStringLiteral("copy-image")}, i18n("In background mode, copy screenshot image to clipboard")},
+        {{QStringLiteral("C"), QStringLiteral("copy-path")}, i18n("In background mode, copy screenshot file path to clipboard")},
+        {{QStringLiteral("w"), QStringLiteral("onclick")}, i18n("Wait for a click before taking screenshot. Invalidates delay")},
+        {{QStringLiteral("i"), QStringLiteral("new-instance")}, i18n("Starts a new GUI instance of spectacle without registering to DBus")},
+        {{QStringLiteral("p"), QStringLiteral("pointer")}, i18n("In background mode, include pointer in the screenshot")},
+        {{QStringLiteral("e"), QStringLiteral("no-decoration")}, i18n("In background mode, exclude decorations in the screenshot")},
     });
 }
 
 void SpectacleCore::doStartDragAndDrop()
 {
     auto lExportManager = ExportManager::instance();
+    if (lExportManager->pixmap().isNull()) {
+        return;
+    }
     QUrl lTempFile = lExportManager->tempSave();
     if (!lTempFile.isValid()) {
         return;
     }
 
     auto lMimeData = new QMimeData;
-    lMimeData->setUrls(QList<QUrl> { lTempFile });
+    lMimeData->setUrls(QList<QUrl>{lTempFile});
     lMimeData->setData(QStringLiteral("application/x-kde-suggestedfilename"), QFile::encodeName(lTempFile.fileName()));
 
     auto lDragHandler = new QDrag(this);
     lDragHandler->setMimeData(lMimeData);
-    lDragHandler->setPixmap(lExportManager->pixmap().scaled(256, 256, Qt::KeepAspectRatioByExpanding, Qt::SmoothTransformation));
+    lDragHandler->setPixmap(lExportManager->pixmap().scaled(256, 256, Qt::KeepAspectRatio, Qt::SmoothTransformation));
     lDragHandler->exec(Qt::CopyAction);
 }
 
@@ -527,7 +540,7 @@ void SpectacleCore::doStartDragAndDrop()
 
 Platform::GrabMode SpectacleCore::toPlatformGrabMode(Spectacle::CaptureMode theCaptureMode)
 {
-    switch(theCaptureMode) {
+    switch (theCaptureMode) {
     case Spectacle::CaptureMode::InvalidChoice:
         return Platform::GrabMode::InvalidChoice;
     case Spectacle::CaptureMode::AllScreens:
@@ -548,7 +561,7 @@ Platform::GrabMode SpectacleCore::toPlatformGrabMode(Spectacle::CaptureMode theC
     return Platform::GrabMode::InvalidChoice;
 }
 
-void SpectacleCore::initGui(int theDelay, bool theIncludePointer, bool theIncludeDecorations)
+void SpectacleCore::ensureGuiInitiad()
 {
     if (!mIsGuiInited) {
         mMainWindow = std::make_unique<KSMainWindow>(mPlatform->supportedGrabModes(), mPlatform->supportedShutterModes());
@@ -558,6 +571,17 @@ void SpectacleCore::initGui(int theDelay, bool theIncludePointer, bool theInclud
 
         mIsGuiInited = true;
     }
+}
+
+void SpectacleCore::initGui(int theDelay, bool theIncludePointer, bool theIncludeDecorations)
+{
+    ensureGuiInitiad();
 
     takeNewScreenshot(ExportManager::instance()->captureMode(), theDelay, theIncludePointer, theIncludeDecorations);
 }
+
+void SpectacleCore::initGuiNoScreenshot()
+{
+    ensureGuiInitiad();
+    screenshotUpdated(QPixmap());
+}
